// lineChart.js
document.addEventListener('DOMContentLoaded', function () {
  // Sample temperature data for 3 different cities (Bangalore, Vancouver, San Francisco)
  const temperatureData = {
    labels: [
      'Jan',
      'Feb',
      'Mar',
      'Apr',
      'May',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Oct',
      'Nov',
      'Dec',
    ],
    datasets: [
      {
        label: 'Temperature',
        backgroundColor: 'rgba(255, 99, 132, 0.2)',
        borderColor: 'rgba(255, 99, 132, 1)',
        borderWidth: 1,
        data: [
          25, 26, 27, 28, 29, 30, 29, 28, 28, 27, 26, 25,
        ], // Sample temperature data for Bangalore
      },
    ],
  };

  // Get reference to the chart container
  const lineChartContainer = document
    .getElementById('line-chart')
    .getContext('2d');

  // Create initial chart
  const lineChart = new Chart(lineChartContainer, {
    type: 'line',
    data: temperatureData,
    options: {},
  });

  // Function to update chart based on selected city
  function updateChart(selectedCity) {
    // Lookup data for the selected city
    const newData = getTemperatureData(selectedCity);
    // Update chart with new data
    lineChart.data.datasets[0].data = newData;
    // Update chart colors based on selected city
    lineChart.data.datasets[0].backgroundColor =
      getBackgroundColor(selectedCity);
    lineChart.data.datasets[0].borderColor =
      getBorderColor(selectedCity);
    // Update chart
    lineChart.update();
  }

  // Function to get temperature data for a specific city
  function getTemperatureData(city) {
    switch (city) {
      case 'Bangalore':
        return [
          25, 26, 27, 28, 29, 30, 29, 28, 28, 27, 26, 25,
        ];
      case 'Vancouver':
        return [5, 6, 7, 10, 14, 18, 21, 21, 18, 13, 8, 5];
      case 'San Francisco':
        return [
          15, 16, 16, 17, 18, 19, 19, 20, 20, 19, 17, 15,
        ];
      default:
        return [];
    }
  }

  // Function to get background color for a specific city
  function getBackgroundColor(city) {
    switch (city) {
      case 'Bangalore':
        return 'rgba(255, 99, 132, 0.2)';
      case 'Vancouver':
        return 'rgba(54, 162, 235, 0.2)';
      case 'San Francisco':
        return 'rgba(255, 206, 86, 0.2)';
      default:
        return 'rgba(255, 99, 132, 0.2)'; // Default color
    }
  }

  // Function to get border color for a specific city
  function getBorderColor(city) {
    switch (city) {
      case 'Bangalore':
        return 'rgba(255, 99, 132, 1)';
      case 'Vancouver':
        return 'rgba(54, 162, 235, 1)';
      case 'San Francisco':
        return 'rgba(255, 206, 86, 1)';
      default:
        return 'rgba(255, 99, 132, 1)'; // Default color
    }
  }

  // Event listener for year selection
  const yearSelect = document.getElementById('year-select');

  yearSelect.addEventListener('change', function () {
    selectedYear = yearSelect.value;
    updateChart(selectedYear, selectedCity);
  });
  document
    .getElementById('bangalore-button')
    .addEventListener('click', function () {
      updateChart('Bangalore');
    });

  document
    .getElementById('vancouver-button')
    .addEventListener('click', function () {
      updateChart('Vancouver');
    });

  document
    .getElementById('san-francisco-button')
    .addEventListener('click', function () {
      updateChart('San Francisco');
    });
});
